<roundcube:object name="doctype" value="html5" />
<html>
<head>
<roundcube:include file="/includes/links.html" />
</head>
<body class="iframe">

<h1 class="boxtitle"><roundcube:object name="steptitle" /></h1>

<div id="preferences-details" class="boxcontent">
<roundcube:object name="responseform" class="propform" size="60" textareacols="60" textarearows="18" />
</div>

<div class="footerleft formbuttons">
	<roundcube:button command="save" type="input" class="button mainaction" label="save" condition="!env:readonly" />
</div>

<roundcube:include file="/includes/footer.html" />

</body>
</html>
